/* 
 * Copyright (C) 2001 Sonal Bansal <sonal_b@yahoo.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.javapal.CellQuotes;

import java.io.*;
import java.util.*;
import java.lang.reflect.*;

/* This class returns appropriate CellProvider implementation for
 * specified ProviderID.
 * It does this by reading registered implementations from the registry
 * and then uses Reflection to determine if that implementation is
 * suitable.
 */
public abstract class CellProviderSelector
{
	private static String CPRegFile = Constants.providerRegistryFile;

	/* Changes the default registry file
	 */
	public static void setRegistryFile(String s)
	{
		CPRegFile = s;
	}

	/* Returns appropriate CellProvider implementation for specified ID.
	 * Null if none was found.
	 */
	public static CellProvider getProvider(String ID)
	{
		try
		{
			String line = null;
			Class classCPC = null;
			Method methodIsMe = null;
			CellProvider cp = null;
			Boolean result = new Boolean(false);
			Class parameterTypes[] = new Class[] {String.class};
			Object args[];
			File fileReg = new File(CPRegFile);
			BufferedReader br = new BufferedReader(new FileReader(fileReg));
			while((line = br.readLine()) != null)
			{
				args = new Object[] {ID};
				classCPC = Class.forName(line);
				cp = (CellProvider) classCPC.newInstance();
				methodIsMe = classCPC.getMethod("isMe",parameterTypes);
				result = (Boolean) methodIsMe.invoke(cp,args);
				if(result.booleanValue() == true)
					break;
			}

			if(result.booleanValue() == true)
			{
				return(cp);
			}
			else
			{
				return(null);
			}
		}
		catch(Exception e)
		{
			e.printStackTrace();
			return(null);
		}
	}
}
