/* 
 * Copyright (C) 2001 Sonal Bansal <sonal_b@yahoo.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.javapal.CellQuotes;

import java.io.*;
import java.util.*;

/* This class encapsulates all the information representing a user's
 * profile/preferences.
 */
public class Profile
{
	public static final int EMAIL_ID = 0;
	public static final int PROVIDER = 1;
	public static final int NUMBER = 2;
	public static final int FREQUENCY = 3;
	public static final int QUOTES = 4;
	public static final int SYMBOLS = 5;
	public static final int NEWS = 6;

	private String profile[] = new String[7];

	private static final int iNumFields = 7;

	/* Constructs a Profile, given all the parameters
	 */
	public Profile(String mail,String prov,String num,String freq,String quot,String sym,String nws)
	{
		try
		{
			String b = quot.toLowerCase().trim();
			if(!b.equals("true") && !b.equals("false"))
			{
				throw new IllegalArgumentException();
			}

			b = nws.toLowerCase().trim();
			if(!b.equals("true") && !b.equals("false"))
			{
				throw new IllegalArgumentException();
			}
		}
		catch(NullPointerException npe)
		{
			throw new IllegalArgumentException();
		}

		setProfile(mail,prov,num,freq,quot,sym,nws);
	}

	/* Constructs an empty Profile
	 */
	public Profile()
	{
		setProfile("","","","1","false","","false");
	}

	/* Constructs a Profile from a Comma Separated Value String,
	 * as extracted by ProfileReader
	 */
	public Profile(String csvProfileStr) throws Exception
	{
		setProfile(csvProfileStr);
	}

	/* Checks if given CSV String has valid number of tokens
	 */
	public static boolean verifyProfile(String csvProfileStr)
	{
		StringTokenizer st = new StringTokenizer(csvProfileStr,",");
		if(st.countTokens() != iNumFields)
			return(false);
		return(true);
	}

	/* Returns requested parameter
	 */
	public String getParameter(int param)
	{
		if(param < EMAIL_ID || param > NEWS)
			throw new IllegalArgumentException("Illegal Field Name");
		return(profile[param]);
	}

	/* Convenience method to retrieve user Frequency
	 */
	public int getFrequency()
	{
		return(Integer.parseInt(profile[FREQUENCY]));
	}

	/* Returns whether user wants stock quotes
	 */
	public boolean getQuotesStatus()
	{
		return((new Boolean(profile[QUOTES])).booleanValue());
	}

	/* Returns whether user wants news headlines
	 */
	public boolean getNewsStatus()
	{
		return((new Boolean(profile[NEWS])).booleanValue());
	}

	/* Sets the value for specified parameter
	 */
	public void setParameter(int ID, String value) throws IllegalArgumentException
	{
		if(ID < EMAIL_ID || ID > NEWS)
			throw new IllegalArgumentException("ID out of bounds.");
		profile[ID] = value;
	}

	/* Sets the user frequency preference
	 */
	public void setFrequency(int freq)
	{
		profile[FREQUENCY] = String.valueOf(freq);
	}

	/* Sets user quote preference
	 */
	public void setQuotesStatus(boolean quot)
	{
		profile[QUOTES] = String.valueOf(quot);
	}

	/* Sets user news preference
	 */
	public void setNewsStatus(boolean news)
	{
		profile[NEWS] = String.valueOf(news);
	}

	public void setProfile(String mail,String prov,String num,String freq,String quot,String sym,String nws)
	{
		profile[EMAIL_ID] = mail;
		profile[PROVIDER] = prov;
		profile[NUMBER] = num;
		profile[FREQUENCY] = freq;
		profile[QUOTES] = quot;
		profile[SYMBOLS] = sym;
		profile[NEWS] = nws;
	}

	public void setProfile(String csvProfileStr)
	{
		StringTokenizer st = new StringTokenizer(csvProfileStr,",");
		int numTokens = st.countTokens();
		if(numTokens != iNumFields)
			throw new IllegalArgumentException("Incorrect number of fields.");
		for(int i=0; i < numTokens;i++)
		{
			profile[i] = st.nextToken();
		}
	}

	public String toCSVString()
	{
		String csvProfile = new String();

		for(int i = 0; i < iNumFields ;i++)
		{
			csvProfile += profile[i];
			if(i != (iNumFields-1))
				csvProfile += ",";
		}
		return(csvProfile);
	}
}
