/* 
 * Copyright (C) 2001 Sonal Bansal <sonal_b@yahoo.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.javapal.CellQuotes;

import java.io.*;

/* This class contains the logic for reading user-profiles 
 * from a flat file, and returns them as Profile objects
 */
public class ProfileReader
{
	private RandomAccessFile profFile = null;
	private int numProfiles = 0;
	private int currentProfile = 0;
	private static final long STARTOFFILE = 0;

	/* Constructs a ProfileReader to read Profiles from specified 
	 * flat file
	 */
	public ProfileReader(File profilesFile) throws Exception
	{
		if(!profilesFile.exists())
		{
			throw new FileNotFoundException("Can't find Profiles File.");
		}
		
		profFile = new RandomAccessFile(profilesFile,"r");
		String line;
		while((line = profFile.readLine()) != null)
		{
			if(Profile.verifyProfile(line) == false)
			{
				profFile.close();
				throw new Exception("Corrupt Profiles File.");
			}
			numProfiles++;
		}
		profFile.seek(STARTOFFILE);
	}

	/* Returns the next Profile
	 */
	public Profile nextProfile() throws Exception
	{
		String line;
		if((line = profFile.readLine()) == null)
		{
			profFile.close();
			throw new NullPointerException();
		}
		currentProfile++;
		return(new Profile(line));
	}

	/* Returns true if there are more Profiles to be read
	 */
	public boolean hasMoreProfiles()
	{
		if(numProfiles - currentProfile == 0)
			return(false);
		return(true);
	}

	/* Returns the number of Profiles which can be read
	 * without causing an Exception
	 */
	public int countProfiles()
	{
		return(numProfiles - currentProfile);
	}

	/* Closes the underlying flat file
	 */
	public void close()
	{
		try
		{
			profFile.close();
		}
		catch(Exception e)
		{
		}
	}
}
