/* 
 * Copyright (C) 2001 Sonal Bansal <sonal_b@yahoo.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.javapal.CellQuotes;

import java.io.*;
import java.util.*;

/* This class contains the logic for writing user-profiles to
 * a flat file. It cannot update profiles, if a user already 
 * exists, it simply does nothing.
 */
public class ProfileWriter
{
	File f;
	private RandomAccessFile profFile;
	private long fileLength = 0;
	private static final long STARTOFFILE = 0;
	private long ENDOFFILE = 0;

	/* Constructs a ProfileWriter to write to specified falt file
	 */	
	public ProfileWriter(File profilesFile) throws IOException
	{
		f = profilesFile;
		profFile = new RandomAccessFile(profilesFile,"rw");
		refreshFileParams();
	}

	/* Refreshes file parameters such as file length
	 */
	private void refreshFileParams() throws IOException
	{
		fileLength = profFile.length();
		ENDOFFILE = fileLength;
		if(ENDOFFILE < 0)
		{
			ENDOFFILE = 0;
		}
	}

	/* Checks if a Profile already exists in the flat file
	 */
	private boolean profileExists(Profile profile) throws IOException
	{
		String line;

		try
		{
			profFile.seek(STARTOFFILE);
			while((line = profFile.readLine()) != null)
			{
				if(line.startsWith(profile.getParameter(profile.EMAIL_ID)) == true)
				{
					long pos = profFile.getFilePointer() - 1;
					pos -= profile.toCSVString().length();
					if(pos < 0)
					{
						pos = 0;
					}
					profFile.seek(pos);
					return(true);
				}
			}
			profFile.seek(ENDOFFILE);
			return(false);
		}
		catch(IOException ioe)
		{
			if(f.exists() == true)
			{
				throw ioe;
			}

			profFile.seek(STARTOFFILE);
			return(false);
		}
	}
	
	/* Writes a Profile to the flat file
	 */	
	public void writeProfile(Profile profile) throws IOException
	{
		if(profileExists(profile))
		{
			return;
		}

		profFile.seek(ENDOFFILE);
		profFile.writeBytes(profile.toCSVString() + "\n");
		refreshFileParams();
		profFile.seek(ENDOFFILE);
	}

	/* Closes underlying flat file
	 */
	public void close()
	{
		try
		{
			profFile.close();
		}
		catch(Exception e)
		{
		}
	}
}
